API docs for “spamfighter.plugins.static_domain_provider.StaticDefaultDomainProvider”

# Class s.p.s.StaticDefaultDomainProvider(object):

Part of spamfighter.plugins.static_domain_provider View Source View In Hierarchy

Провайдер статического дефолтного домена.

Method | __init__ | Конструктор.
Method | name | Получить имя плагина.
Method | getDefaultDomain | Получить домен по умолчанию в системе.

def __init__(self, name, dict, parent=None): (source)
Конструктор.

Parameters | name | имя плагина-домена (type: `str` )
| dict | содержимое домена (type: `dict` )

def name(self): (source)
Получить имя плагина.

Returns | имя плагина (type: `str` )

def getDefaultDomain(self): (source)
Получить домен по умолчанию в системе.

Returns | домен по умолчанию. (type: `spamfighter.interfaces.IDomain` )